==> qtjambi-qt3drender-5.15.4-sources.jar: io/qt/qt3d/render/QRasterMode.java <==
package io.qt.qt3d.render;


/**
 * <p>Render state allows to control the type of rasterization to be performed</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html">Qt3DRender::QRasterMode</a></p>
 */
public class QRasterMode extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRasterMode.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#FaceMode-enum">Qt3DRender::QRasterMode::FaceMode</a></p>
     */
    public enum FaceMode implements io.qt.QtEnumerator {
        Front(1028),
        Back(1029),
        FrontAndBack(1032);

        private FaceMode(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static FaceMode resolve(int value) {
            switch (value) {
            case 1028: return Front;
            case 1029: return Back;
            case 1032: return FrontAndBack;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#RasterMode-enum">Qt3DRender::QRasterMode::RasterMode</a></p>
     */
    public enum RasterMode implements io.qt.QtEnumerator {
        Points(6912),
        Lines(6913),
        Fill(6914);

        private RasterMode(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static RasterMode resolve(int value) {
            switch (value) {
            case 6912: return Points;
            case 6913: return Lines;
            case 6914: return Fill;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#faceMode-prop">Qt3DRender::QRasterMode::faceModeChanged(Qt3DRender::QRasterMode::FaceMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="faceMode")
    public final Signal1<io.qt.qt3d.render.QRasterMode.FaceMode> faceModeChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#rasterMode-prop">Qt3DRender::QRasterMode::rasterModeChanged(Qt3DRender::QRasterMode::RasterMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="rasterMode")
    public final Signal1<io.qt.qt3d.render.QRasterMode.RasterMode> rasterModeChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QRasterMode(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRasterMode() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QRasterMode(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRasterMode instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#faceMode-prop">Qt3DRender::QRasterMode::faceMode()const</a></p>
     */
    @io.qt.QtPropertyReader(name="faceMode")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QRasterMode.FaceMode faceMode(){
        return io.qt.qt3d.render.QRasterMode.FaceMode.resolve(faceMode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int faceMode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#rasterMode-prop">Qt3DRender::QRasterMode::rasterMode()const</a></p>
     */
    @io.qt.QtPropertyReader(name="rasterMode")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QRasterMode.RasterMode rasterMode(){
        return io.qt.qt3d.render.QRasterMode.RasterMode.resolve(rasterMode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int rasterMode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#faceMode-prop">Qt3DRender::QRasterMode::setFaceMode(Qt3DRender::QRasterMode::FaceMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="faceMode")
    public final void setFaceMode(io.qt.qt3d.render.QRasterMode.FaceMode faceMode){
        setFaceMode_native_Qt3DRender_QRasterMode_FaceMode(QtJambi_LibraryUtilities.internal.nativeId(this), faceMode.value());
    }
    
    private native void setFaceMode_native_Qt3DRender_QRasterMode_FaceMode(long __this__nativeId, int faceMode);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#rasterMode-prop">Qt3DRender::QRasterMode::setRasterMode(Qt3DRender::QRasterMode::RasterMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="rasterMode")
    public final void setRasterMode(io.qt.qt3d.render.QRasterMode.RasterMode rasterMode){
        setRasterMode_native_Qt3DRender_QRasterMode_RasterMode(QtJambi_LibraryUtilities.internal.nativeId(this), rasterMode.value());
    }
    
    private native void setRasterMode_native_Qt3DRender_QRasterMode_RasterMode(long __this__nativeId, int rasterMode);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRasterMode(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRasterMode(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRasterMode instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QRasterMode.java <==
package io.qt.qt3d.render;


/**
 * <p>Render state allows to control the type of rasterization to be performed</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html">Qt3DRender::QRasterMode</a></p>
 */
public class QRasterMode extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRasterMode.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#FaceMode-enum">Qt3DRender::QRasterMode::FaceMode</a></p>
     */
    public enum FaceMode implements io.qt.QtEnumerator {
        Front(1028),
        Back(1029),
        FrontAndBack(1032);

        private FaceMode(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static FaceMode resolve(int value) {
            switch (value) {
            case 1028: return Front;
            case 1029: return Back;
            case 1032: return FrontAndBack;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#RasterMode-enum">Qt3DRender::QRasterMode::RasterMode</a></p>
     */
    public enum RasterMode implements io.qt.QtEnumerator {
        Points(6912),
        Lines(6913),
        Fill(6914);

        private RasterMode(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static RasterMode resolve(int value) {
            switch (value) {
            case 6912: return Points;
            case 6913: return Lines;
            case 6914: return Fill;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#faceMode-prop">Qt3DRender::QRasterMode::faceModeChanged(Qt3DRender::QRasterMode::FaceMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="faceMode")
    public final Signal1<io.qt.qt3d.render.QRasterMode.FaceMode> faceModeChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#rasterMode-prop">Qt3DRender::QRasterMode::rasterModeChanged(Qt3DRender::QRasterMode::RasterMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="rasterMode")
    public final Signal1<io.qt.qt3d.render.QRasterMode.RasterMode> rasterModeChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QRasterMode(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRasterMode() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QRasterMode(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRasterMode instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#faceMode-prop">Qt3DRender::QRasterMode::faceMode()const</a></p>
     */
    @io.qt.QtPropertyReader(name="faceMode")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QRasterMode.FaceMode faceMode(){
        return io.qt.qt3d.render.QRasterMode.FaceMode.resolve(faceMode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int faceMode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#rasterMode-prop">Qt3DRender::QRasterMode::rasterMode()const</a></p>
     */
    @io.qt.QtPropertyReader(name="rasterMode")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QRasterMode.RasterMode rasterMode(){
        return io.qt.qt3d.render.QRasterMode.RasterMode.resolve(rasterMode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int rasterMode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#faceMode-prop">Qt3DRender::QRasterMode::setFaceMode(Qt3DRender::QRasterMode::FaceMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="faceMode")
    public final void setFaceMode(io.qt.qt3d.render.QRasterMode.FaceMode faceMode){
        setFaceMode_native_Qt3DRender_QRasterMode_FaceMode(QtJambi_LibraryUtilities.internal.nativeId(this), faceMode.value());
    }
    
    private native void setFaceMode_native_Qt3DRender_QRasterMode_FaceMode(long __this__nativeId, int faceMode);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrastermode.html#rasterMode-prop">Qt3DRender::QRasterMode::setRasterMode(Qt3DRender::QRasterMode::RasterMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="rasterMode")
    public final void setRasterMode(io.qt.qt3d.render.QRasterMode.RasterMode rasterMode){
        setRasterMode_native_Qt3DRender_QRasterMode_RasterMode(QtJambi_LibraryUtilities.internal.nativeId(this), rasterMode.value());
    }
    
    private native void setRasterMode_native_Qt3DRender_QRasterMode_RasterMode(long __this__nativeId, int rasterMode);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRasterMode(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRasterMode(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRasterMode instance, QDeclarativeConstructor constructor);
    
}
